@@ -89,7 +89,7 @@ as.data.frame.CrunchDataFrame <- function(x,
     write.csv(ds, tmp, categorical = "id", include.hidden = include.hidden)
     # TODO: use variableMetadata to provide all `colClasses`?
     # meta <- variableMetadata(ds)
-    ds_out <- read.csv(tmp, stringsAsFactors = FALSE)
+    ds_out <- read.csv(tmp, stringsAsFactors = FALSE, check.names = FALSE)
     return(csvToDataFrame(ds_out, x))
 }
 
@@ -207,16 +207,6 @@ as.data.frame.FilterCatalog <- function(x,
     catalogToDataFrame(x, keys = keys, row.names = row.names, ...)
 }
 
-#' @rdname catalog-dataframes
-#' @export
-as.data.frame.ProjectCatalog <- function(x,
-                                         row.names = NULL,
-                                         optional = FALSE,
-                                         keys = c("name", "id", "description"),
-                                         ...) {
-    catalogToDataFrame(x, keys = keys, row.names = row.names, ...)
-}
-
 #' @rdname catalog-dataframes
 #' @export
 as.data.frame.UserCatalog <- function (x, row.names = NULL,
