@@ -1,3 +1,6 @@
+#' @include transform.R
+NULL
+
 #' @rdname showTransforms
 #' @export
 setMethod("showTransforms", "CrunchCube", function(x) {
@@ -142,11 +145,11 @@ applyTransforms <- function(x,
     # evaluate which categories should be kept
     keep_cats <- evalUseNA(array, dims_list, useNA = useNA)
 
-    # TODO: separate out the calculation of subtotals from others (like summary 
-    # stats) since a subtotal can have a mean, we need to calculate all 
-    # subtotals first and then calculate. Alternatively, change the process for 
+    # TODO: separate out the calculation of subtotals from others (like summary
+    # stats) since a subtotal can have a mean, we need to calculate all
+    # subtotals first and then calculate. Alternatively, change the process for
     # insertion function generation.
-    
+
     # Try to calculate the transforms for any dimension that has them, but
     # fail silently if they aren't calculable We use a for loop so that failing
     # one dimension doesn't break others. We could possibly use something like
@@ -169,10 +172,10 @@ applyTransforms <- function(x,
             }
 
             var_cats <- Categories(data = variables(dims_list)[[d]]$categories)
-            
+
             # TODO: calculate category/element changes
-        
-            # make a list of insertion functions to be used when calculating 
+
+            # make a list of insertion functions to be used when calculating
             # below
             insert_funcs <- makeInsertionFunctions(
                 # only the kept categories must be passed
@@ -213,11 +216,11 @@ applyTransforms <- function(x,
 # those that they shouldn't be (for example, don't treat means as if they were
 # actually counts and do weighted means of the means)
 maskAndApplyInserts <- function(array, na_mask, d, insert_funcs) {
-    # get the coordinates of in the array that must be masked and turn them into 
+    # get the coordinates of in the array that must be masked and turn them into
     # NAs
     var_coord_cols <- startsWith(colnames(na_mask), "Var")
     array[as.matrix(na_mask[,var_coord_cols])] <- NA
-    
+
     # do the actual transforms calculations for the dimension d
     array <- applyAgainst(
         X = array,
@@ -226,13 +229,13 @@ maskAndApplyInserts <- function(array, na_mask, d, insert_funcs) {
         insert_funcs = insert_funcs,
         dim_names = names(insert_funcs)
     )
-    
+
     # replace any values that had been masked with their previous values. We
     # only have to do this if the na_mask has anything in it, and it will break
     # if there's nothing in it
     insert_types <- attributes(insert_funcs)$types
     if (length(na_mask) > 0) {
-        # we use the id_map to map from positions in just the categories to the 
+        # we use the id_map to map from positions in just the categories to the
         # positions after things have been inserted.
         id_map <- which(insert_types == "Category")
         names(id_map) <- seq_along(id_map)
@@ -243,11 +246,11 @@ maskAndApplyInserts <- function(array, na_mask, d, insert_funcs) {
         }
         array[as.matrix(na_mask[,var_coord_cols])] <- na_mask$values
     }
-    
-    return(array)
-} 
 
-# given an array, na_mask, and insertion functions calculate a new na_mask that 
+    return(array)
+}
+
+# given an array, na_mask, and insertion functions calculate a new na_mask that
 # adds which elements in dimension d must be masked before further calculation
 calculate_na_mask <- function(array, na_mask, d, insert_funcs) {
     # Find the coordinates of the cells that must be masked (for now this is
@@ -256,13 +259,13 @@ calculate_na_mask <- function(array, na_mask, d, insert_funcs) {
     ind_to_mask <- which(attributes(insert_funcs)$types == "SummaryStat")
     coords <- lapply(dim(array), function(to) seq_len(to))
     coords[[d]] <- ind_to_mask
-    
-    # add the new set of coordinates to the old na_mask since we iteratively 
+
+    # add the new set of coordinates to the old na_mask since we iteratively
     # apply transforms
     na_mask_new <- expand.grid(coords)
     na_mask_new$values <- array[as.matrix(na_mask_new)]
     na_mask <- rbind(na_mask, na_mask_new)
-    
+
     return(na_mask)
 }
 
@@ -316,18 +319,18 @@ makeTransFuncs <- function(cat_insert_map, cats_in_array, var_cats) {
                 # not have them
                 return(NULL)
             }
-            
+
             id <- which(ids(var_cats) %in% id(element))
             which.cat <- names(var_cats[id])
             return(function(vec) vec[[which.cat]])
         }
-        
+
         # if element is a heading return NA (since there is no value to be
         # calculated but we need a placeholder non-number)
         if (is.Heading(element)) {
             return(function(vec) NA)
         }
-        
+
         # if element is a subtotal, sum the things it corresponds to which are
         # found with arguments()
         if (is.Subtotal(element)) {
@@ -337,15 +340,15 @@ makeTransFuncs <- function(cat_insert_map, cats_in_array, var_cats) {
             which.cats <- names(var_cats[combo_ids])
             return(function(vec) sum(vec[which.cats]))
         }
-        
-        # if element is a summaryStat, grab the function from 
+
+        # if element is a summaryStat, grab the function from
         # summaryStatInsertions to use.
         if (is.SummaryStat(element)) {
             statFunc <- summaryStatInsertions[[func(element)]](element, var_cats)
-            
+
             return(function(vec) statFunc(vec))
         }
-        
+
         # finally, check if there are other functions, if there are warn, and
         # then return NA
         known_inserts <- c("subtotal", names(summaryStatInsertions))
@@ -369,19 +372,19 @@ getInsertionTypes <- function(cat_insert_map, cats_in_array) {
             }
             return("Category")
         }
-        
+
         if (is.Heading(element)) {
             return("Heading")
         }
-        
+
         if (is.Subtotal(element)) {
             return("Subtotal")
         }
-        
+
         if (is.SummaryStat(element)) {
             return("SummaryStat")
         }
-        
+
         known_inserts <- c("subtotal", names(summaryStatInsertions))
         unknown_funcs <- !(element[["function"]] %in% known_inserts)
         if (unknown_funcs) {
@@ -615,7 +618,7 @@ setMethod("transforms<-", c("CrunchCube", "ANY"), function(x, value) {
     return(invisible(x))
 })
 
-#' @rdname Transforms
+#' @rdname crunch-extract
 #' @export
 setMethod("[[<-", c("TransformsList", "ANY", "missing", "NULL"), function(x,
                                                                           i,
