@@ -51,3 +51,33 @@ appendStream <- function(ds) {
 
     return(ds)
 }
+
+
+#' Set the streaming property of a dataset
+#'
+#' Only datasets that have their streaming property set to "streaming" can
+#' have rows streamed to them. Before attempting to streaming rows (with
+#' [streamRows] for example), the dataset has to be set up to stream rows. Use
+#' `streaming(ds)` to get the streaming status, and `streaming(ds) <-
+#' "streaming"` to set the streaming status.
+#' 
+#' @param x a CrunchDataset
+#' @param value for setting only (values can be: `"no"`, `"streaming"`, or
+#' `"finished"`)
+#' 
+#' @return the streaming status
+#' @rdname streaming
+#' @export
+streaming <- function(x) {
+    stopifnot(is.dataset(x))
+    return(x@body$streaming)
+}
+
+#' @rdname streaming
+#' @export
+`streaming<-` <- function(x, value = c("no", "streaming", "finished")) {
+    stopifnot(is.dataset(x))
+    value <- match.arg(value)
+    return(setEntitySlot(x, "streaming", value))
+}
+
