@@ -4,6 +4,16 @@ rethrow <- function(x) halt(errorMessage(x))
 
 errorMessage <- function(e) attr(e, "condition")$message
 
+warn_once <- function(..., call.=FALSE, option) {
+    # Warn the first time, then set an option so we know not to warn again in
+    # the current session
+    if (!isTRUE(getOption(option, FALSE))) {
+        warning(..., call.=call.)
+        opts <- structure(list(TRUE), .Names=option)
+        do.call(options, opts)
+    }
+}
+
 vget <- function(name) {
     ## Return a function you can lapply/vapply to select an attribute
     ## Usage: lapply(list.of.stuff, vget("name"))
@@ -233,37 +243,6 @@ haltIfArray <- function(variable, callingFunc) {
     halt("Array-like variables can't be used.")
 }
 
-# validate that rollup resolutions are what are allowed by Crunch
-validateResolution <- function(resolution) {
-    valid_res <- c("Y", "Q", "M", "W", "D", "h", "m", "s", "ms")
-
-    if (!is.null(resolution) && !(resolution %in% valid_res)) {
-        halt(
-            dQuote("resolution"), " is invalid. Valid values are ",
-            serialPaste(valid_res, collapse = "or")
-        )
-    }
-}
-
-# default formats for various resolutions
-datetimeFormater <- function(resolution) {
-    validateResolution(resolution)
-    formats <- list(
-        "Y" = "%Y",
-        # there is no %q in python strftime, so can't print quarters
-        "Q" = "%Y-%m-%d",
-        "M" = "%Y-%m",
-        "W" = "%Y W%W",
-        "D" = "%Y-%m-%d",
-        "h" = "%Y-%m-%d %H:00",
-        "m" = "%Y-%m-%d %H:%M",
-        "s" = "%Y-%m-%d %H:%M:%S",
-        "ms" = "%Y-%m-%d %H:%M:%S.%f"
-    )
-    # return format based on rollup or default of "s"
-    return(formats[[resolution %||% "s"]])
-}
-
 #' Check that a value is TRUE or FALSE
 #'
 #' @param value Value to check
@@ -324,3 +303,8 @@ escapeRegex <- function(string) {
     out <- gsub("([.|()\\^{}+$*?])", "\\\\\\1", string)
     return(gsub("(\\[|\\])", "\\\\\\1", out))
 }
+
+pluralize <- function (string, count) {
+    # Naive conditional pluralization
+    ifelse(count == 1, string, paste0(string, "s"))
+}
