@@ -9,7 +9,10 @@
 #' `ordering<-` sets the VariableOrder
 #' @name ordering
 #' @aliases ordering ordering<-
-NULL
+#' @keywords internal
+setGeneric("ordering", function(x) standardGeneric("ordering"))
+#' @rdname ordering
+setGeneric("ordering<-", function(x, value) standardGeneric("ordering<-"))
 
 #' @rdname ordering
 #' @export
@@ -37,24 +40,22 @@ setMethod("ordering<-", "VariableCatalog", function(x, value) {
 
     if (!identical(ordering(x)@graph, value@graph)) {
         ## Give deprecation warning (the first time only per session)
-        if (!isTRUE(getOption("crunch.already.shown.folders.msg", FALSE))) {
-            warning(paste(
-                "Hey! There's a new way to organize variables within",
-                "datasets: the 'folder' methods. They're easier to use and",
-                "more reliable. See `?mv`, `?cd`, and others for details, and",
-                "`vignettes('variable-order', package='crunch')` for examples.",
-                "You're seeing this message because you're still using the",
-                "ordering<- method, which is fine today, but it will be going",
-                "away in the future, so check out the new methods."
-            ))
-            options(crunch.already.shown.folders.msg = TRUE)
-        }
+        warn_once(
+            "Hey! There's a new way to organize variables within ",
+            "datasets: the 'folder' methods. They're easier to use and ",
+            "more reliable. See `?mv`, `?cd`, and others for details, and ",
+            "`vignettes('variable-order', package='crunch')` for examples. ",
+            "You're seeing this message because you're still using the ",
+            "ordering<- method, which is fine today, but it will be going ",
+            "away in the future, so check out the new methods. ",
+            option="crunch.already.shown.folders.msg"
+        )
 
         ## Validate.
         bad.entities <- setdiff(urls(value), urls(x))
         if (length(bad.entities)) {
             halt(
-                "Variable URL", ifelse(length(bad.entities) > 1, "s", ""),
+                pluralize("Variable URL", length(bad.entities)),
                 " referenced in Order not present in catalog: ",
                 serialPaste(bad.entities)
             )
@@ -74,6 +75,7 @@ setMethod("ordering<-", "VariableCatalog", function(x, value) {
 #' @rdname ordering
 #' @export
 setMethod("ordering", "DatasetCatalog", function(x) {
+    .Deprecated(msg="dataset 'ordering' is deprecated. Use the dataset folder API instead. See 'vignette(\"projects\")'.")
     out <- DatasetOrder(crGET(shojiURL(x, "orders", "order")))
     out@catalog_url <- self(x)
     return(out)
@@ -82,28 +84,28 @@ setMethod("ordering", "DatasetCatalog", function(x) {
 #' @rdname ordering
 #' @export
 setMethod("ordering", "ProjectFolder", function(x) {
-    return(ordering(datasets(x)))
+    out <- DatasetCatalog(crGET(shojiURL(x, "catalogs", "datasets")))
+    return(ordering(out))
 })
 
-#' @rdname ordering
-#' @export
-setMethod("ordering<-", "DatasetCatalog", function(x, value) {
+.stopDatasetOrderSetter <- function(x, value) {
     halt(
         "Hi there! `ordering<-` no longer works to organize datasets. ",
         " There's a new way to organize datasets within ",
         "projects: the 'folder' methods. They're easier to use and ",
         "more reliable, just like the folder methods for organizing ",
-        "variables. See `vignettes('projects', package='crunch')` for ",
+        "variables. See `vignette('projects', package='crunch')` for ",
         "details."
     )
-})
+}
 
 #' @rdname ordering
 #' @export
-setMethod("ordering<-", "ProjectFolder", function(x, value) {
-    ordering(datasets(x)) <- value
-    return(x)
-})
+setMethod("ordering<-", "DatasetCatalog", .stopDatasetOrderSetter)
+
+#' @rdname ordering
+#' @export
+setMethod("ordering<-", "ProjectFolder", .stopDatasetOrderSetter)
 
 #' Copy the variable order from one dataset to another.
 #'
