@@ -21,16 +21,14 @@ variableGroupEntitiesInit <- function(x) {
 setMethod("entitiesInitializer", "VariableOrder", variableGroupEntitiesInit)
 setMethod("entitiesInitializer", "VariableGroup", variableGroupEntitiesInit)
 
-#' @rdname ShojiOrder-extract
+#' @rdname crunch-extract
 #' @export
-setMethod(
-    "[[<-", c("VariableOrder", "character", "missing", "CrunchDataset"),
+setMethod("[[<-", c("VariableOrder", "character", "missing", "CrunchDataset"),
     .setNestedGroupByName
 )
 
-#' @rdname ShojiOrder-extract
+#' @rdname crunch-extract
 #' @export
-setMethod(
-    "[[<-", c("VariableGroup", "character", "missing", "CrunchDataset"),
+setMethod("[[<-", c("VariableGroup", "character", "missing", "CrunchDataset"),
     .setNestedGroupByName
 )
