@@ -343,51 +343,6 @@ with_mock_crunch({
     test_that("c(Categories, Categories)", {
         expect_true(is.categories(c(cats, cats2)))
     })
-
-    test_that("changeCategoryID errors with bad inputs", {
-        expect_error(
-            ds$birthyr <- changeCategoryID(ds$birthyr, 1, 6),
-            "The variable Birth Year doesn't have categories."
-        )
-        expect_error(
-            ds$gender <- changeCategoryID(ds$gender, 1, -1),
-            "Id -1 is already a category, please provide a new category id."
-        )
-        expect_error(
-            ds$gender <- changeCategoryID(ds$gender, "not a numeric", 1),
-            "from should be a single numeric"
-        )
-        expect_error(
-            ds$gender <- changeCategoryID(ds$gender, "not a numeric", c(1, -1)),
-            "from should be a single numeric"
-        )
-        expect_error(
-            ds$gender <- changeCategoryID(ds$gender, c(1, -1), 99),
-            "from should be a single numeric"
-        )
-        expect_error(
-            ds$gender <- changeCategoryID(ds$gender, 1, "not a numeric"),
-            "to should be a single numeric"
-        )
-        expect_error(
-            ds$gender <- changeCategoryID(ds$gender, 99, c(1, -1)),
-            "to should be a single numeric"
-        )
-        expect_error(
-            ds$gender <- changeCategoryID(ds$gender, 8, 9),
-            "No category with id 8"
-        )
-    })
-    expect_PATCH(
-        changeCategoryID(ds$gender, 2, 6),
-        "https://app.crunch.io/api/datasets/1/variables/gender/",
-        paste0(
-            '{"categories":[{"id":1,"missing":false,"name":"Male",',
-            '"numeric_value":1},{"id":2,"missing":false,"name":',
-            '"__TO_DELETE__","numeric_value":2},{"id":-1,',
-            '"missing":true,"name":"No Data","numeric_value":null}]}'
-        )
-    )
 })
 
 
@@ -524,195 +479,6 @@ with_test_authentication({
                 array(c(10, 10), dim = 2L, dimnames = list(v4 = c("B", "D")))
             )
         })
-
-        test_that("Can changeCategoryID", {
-            ds$v4f <- df$v4
-            expect_identical(
-                names(categories(ds$v4f)),
-                c("B", "C", "No Data")
-            )
-            expect_equal(
-                ids(categories(ds$v4f)),
-                c(1, 2, -1)
-            )
-            orig_vector <- as.vector(ds$v4f)
-            expect_equal(as.vector(ds$v4f[1:4], mode = "id"), c(1, 2, 1, 2))
-
-            expect_silent(ds$v4f <- changeCategoryID(ds$v4f, 2, 6))
-            expect_identical(
-                names(categories(ds$v4f)),
-                c("B", "C", "No Data")
-            )
-            expect_equal(
-                ids(categories(ds$v4f)),
-                c(1, 6, -1)
-            )
-            expect_equal(as.vector(ds$v4f), orig_vector)
-            expect_equal(as.vector(ds$v4f[1:4], mode = "id"), c(1, 6, 1, 6))
-            expect_equal(as.vector(ds$v4f[1:4], mode = "numeric"), c(1, 6, 1, 6))
-        })
-
-        test_that("Can changeCategoryID with an exclusion", {
-            ds <- newDataset(data.frame(
-                one = factor(rep(LETTERS[3:1], 10), levels = LETTERS[3:1]),
-                two = factor(c(
-                    rep(LETTERS[1], 10),
-                    rep(LETTERS[2], 10),
-                    rep(LETTERS[3], 10)
-                ))
-            ), name = "ds with exclusion")
-
-            # set exclusion
-            exclusion(ds) <- ds$two == "C"
-            expect_identical(
-                names(categories(ds$one)),
-                c("C", "B", "A", "No Data")
-            )
-            expect_equal(
-                ids(categories(ds$one)),
-                c(1, 2, 3, -1)
-            )
-            orig_vector <- as.vector(ds$one)
-            expect_equal(
-                as.vector(ds$one[1:3], mode = "id"),
-                c(1, 2, 3)
-            )
-
-            expect_warning(ds$one <- changeCategoryID(ds$one, 2, 4),
-                paste0(
-                    "Temporarily disabling the exclusion while ",
-                    "changing category IDs. See ",
-                    "`?changeCategoryID` for more information."
-                ),
-                fixed = TRUE
-            )
-            expect_identical(
-                names(categories(ds$one)),
-                c("C", "B", "A", "No Data")
-            )
-            expect_equal(
-                ids(categories(ds$one)),
-                c(1, 4, 3, -1)
-            )
-            orig_vector <- as.vector(ds$one)
-            expect_equal(
-                as.vector(ds$one[1:3], mode = "id"),
-                c(1, 4, 3)
-            )
-            # and finally, the exclusion is back
-            expect_equivalent(exclusion(ds), ds$two == "C")
-        })
-
-        test_that("Can changeCategoryID without changing values when value!=id", {
-            ds$v4g <- df$v4
-            values(categories(ds$v4g)) <- c(NA, 20, NA)
-            expect_identical(
-                names(categories(ds$v4g)),
-                c("B", "C", "No Data")
-            )
-            expect_equal(
-                ids(categories(ds$v4g)),
-                c(1, 2, -1)
-            )
-            expect_equal(
-                values(categories(ds$v4g)),
-                c(NA, 20, NA)
-            )
-            orig_vector <- as.vector(ds$v4g)
-            expect_equal(as.vector(ds$v4g[1:4], mode = "id"), c(1, 2, 1, 2))
-
-
-            expect_silent(ds$v4g <- changeCategoryID(ds$v4g, 2, 6))
-            expect_identical(
-                names(categories(ds$v4g)),
-                c("B", "C", "No Data")
-            )
-            expect_equal(
-                ids(categories(ds$v4g)),
-                c(1, 6, -1)
-            )
-            expect_equal(
-                values(categories(ds$v4g)),
-                c(NA, 20, NA)
-            )
-            expect_equal(as.vector(ds$v4g), orig_vector)
-            expect_equal(as.vector(ds$v4g[1:4], mode = "id"), c(1, 6, 1, 6))
-            expect_equal(as.vector(ds$v4g[1:4], mode = "numeric"), c(NA, 20, NA, 20))
-
-            # also try with an NA, make sure the NA is retained
-            expect_silent(ds$v4g <- changeCategoryID(ds$v4g, 1, 10))
-            expect_identical(
-                names(categories(ds$v4g)),
-                c("B", "C", "No Data")
-            )
-            expect_equal(
-                ids(categories(ds$v4g)),
-                c(10, 6, -1)
-            )
-            expect_equal(
-                values(categories(ds$v4g)),
-                c(NA, 20, NA)
-            )
-            expect_equal(as.vector(ds$v4g[1:4], mode = "id"), c(10, 6, 10, 6))
-            expect_equal(as.vector(ds$v4g[1:4], mode = "numeric"), c(NA, 20, NA, 20))
-        })
-
-        test_that("Can changeCategoryID for array variables", {
-            ds_apidocs <- newDatasetFromFixture("apidocs")
-            # categorical array variables
-            expect_identical(
-                names(categories(ds_apidocs$petloc)),
-                c("Cat", "Dog", "Bird", "Skipped", "Not Asked")
-            )
-            expect_equal(
-                ids(categories(ds_apidocs$petloc)),
-                c(1, 2, 3, 8, 9)
-            )
-            expect_equal(dim(as.vector(ds_apidocs$petloc)), c(20, 2))
-            orig_vector <- as.vector(ds_apidocs$petloc)
-            expect_equal(
-                as.vector(ds_apidocs$petloc[1:4], mode = "id"),
-                data.frame(
-                    petloc_home = c(8, 2, 9, 9),
-                    petloc_work = c(9, 3, 3, 2)
-                )
-            )
-
-            ds_apidocs$petloc <- changeCategoryID(ds_apidocs$petloc, 2, 6)
-            expect_identical(
-                names(categories(ds_apidocs$petloc)),
-                c("Cat", "Dog", "Bird", "Skipped", "Not Asked")
-            )
-            expect_equal(
-                ids(categories(ds_apidocs$petloc)),
-                c(1, 6, 3, 8, 9)
-            )
-            expect_equal(dim(as.vector(ds_apidocs$petloc)), c(20, 2))
-            expect_equal(as.vector(ds_apidocs$petloc), orig_vector)
-            expect_equal(
-                as.vector(ds_apidocs$petloc[1:4], mode = "id"),
-                data.frame(
-                    petloc_home = c(8, 6, 9, 9),
-                    petloc_work = c(9, 3, 3, 6)
-                )
-            )
-            # multiple response variables
-            orig_vector <- as.vector(ds_apidocs$allpets[[1]])
-            expect_equal(ids(categories(ds_apidocs$allpets)), c(2, 1, 9, 8))
-            expect_equal(
-                names(categories(ds_apidocs$allpets)),
-                c("not selected", "selected", "not asked", "skipped")
-            )
-
-            ds_apidocs$allpets <- changeCategoryID(ds_apidocs$allpets, 2, 6)
-            ds_apidocs$allpets <- changeCategoryID(ds_apidocs$allpets, 9, 7)
-            expect_equal(as.vector(ds_apidocs$allpets[[1]]), orig_vector)
-            expect_equal(ids(categories(ds_apidocs$allpets)), c(6, 1, 7, 8))
-            expect_equal(
-                names(categories(ds_apidocs$allpets)),
-                c("not selected", "selected", "not asked", "skipped")
-            )
-        })
     })
 
     whereas("When manipulating categories of array variables", {
