@@ -13,38 +13,6 @@ test_that("bin CrunchExpr", {
     )
 })
 
-test_that("rollup CrunchExpr from zcl variable", {
-    x <- list(variable = "test") ## "ZCL"
-    expect_is(rollup(x), "CrunchExpr")
-    expect_identical(
-        zcl(rollup(x)),
-        list(`function` = "rollup", args = list(
-            list(variable = "test"),
-            list(value = NULL)
-        ))
-    )
-
-    expect_is(rollup(x, resolution = "Y"), "CrunchExpr")
-    expect_identical(
-        zcl(rollup(x, resolution = "Y")),
-        list(`function` = "rollup", args = list(
-            list(variable = "test"),
-            list(value = "Y")
-        ))
-    )
-})
-
-test_that("rollup resolution validation", {
-    expect_error(
-        rollup("a", resolution = "Invalid"),
-        " is invalid. Valid values are "
-    )
-    expect_error(
-        rollup("a", resolution = 42),
-        " is invalid. Valid values are "
-    )
-})
-
 test_that("cube missing functions set @useNA", {
     cube <- loadCube(test_path("cubes/cat-x-mr-x-mr.json"))
     expect_equal(cube@useNA, "no")
@@ -55,43 +23,6 @@ test_that("cube missing functions set @useNA", {
 
 with_mock_crunch({
     ds <- loadDataset("test ds")
-    v <- ds$starttime
-
-    test_that("rollup CrunchExpr from DatetimeVariable", {
-        expect_is(rollup(v), "CrunchExpr")
-        expect_identical(
-            zcl(rollup(v)),
-            list(
-                `function` = "rollup",
-                args = list(
-                    list(variable = "https://app.crunch.io/api/datasets/1/variables/starttime/"),
-                    list(value = "s")
-                )
-            )
-        )
-        expect_is(rollup(v, resolution = "Y"), "CrunchExpr")
-        expect_identical(
-            zcl(rollup(v, resolution = "Y")),
-            list(
-                `function` = "rollup",
-                args = list(
-                    list(variable = "https://app.crunch.io/api/datasets/1/variables/starttime/"),
-                    list(value = "Y")
-                )
-            )
-        )
-        expect_is(rollup(v, resolution = NULL), "CrunchExpr")
-        expect_identical(
-            zcl(rollup(v, resolution = NULL)),
-            list(
-                `function` = "rollup",
-                args = list(
-                    list(variable = "https://app.crunch.io/api/datasets/1/variables/starttime/"),
-                    list(value = NULL)
-                )
-            )
-        )
-    })
 
     test_that("formulaToCubeQuery", {
         expect_identical(
@@ -480,14 +411,14 @@ with_test_authentication({
 
     test_that("prop.table on univariate cube", {
         expect_equivalent(
-            prop.table(crtabs(~bin(v3 + 5), data = ds)),
+            as.array(prop.table(crtabs(~bin(v3 + 5), data = ds))),
             arrayify(c(2, 5, 5, 5, 3) / 20, "v3")
         )
     })
 
     test_that("prop.table on crosstab", {
         expect_equivalent(
-            prop.table(crtabs(~bin(v3) + v7, data = ds)),
+            as.array(prop.table(crtabs(~bin(v3) + v7, data = ds))),
             arrayify(c(
                 2, 5, 3, 0, 0,
                 0, 0, 0, 2, 3
