@@ -13,7 +13,8 @@ with_mock_crunch({
             generateCutLabels(2, c(2.111111, 3, 4, 5), 4, FALSE, FALSE),
             c("[2.1,3)", "[3,4)", "[4,5)")
         )
-        expect_identical(generateCutLabels(2, c(2, 3, 4, 5), 4, FALSE, FALSE),
+        expect_identical(
+            generateCutLabels(2, c(2, 3, 4, 5), 4, FALSE, FALSE),
             c("[2,3)", "[3,4)", "[4,5)")
         )
         expect_identical(
@@ -27,17 +28,23 @@ with_mock_crunch({
         # if the breaks are all the same at up to 12 decimal points
         # generateCutLabels will use Range_n lagles.
         expect_identical(
-            generateCutLabels(5,
-                              c(2.111111111111, 2.111111111112,
-                                2.111111111113, 2.111111111114),
-                              4, FALSE, FALSE),
+            generateCutLabels(
+                5,
+                c(
+                    2.111111111111, 2.111111111112,
+                    2.111111111113, 2.111111111114
+                ),
+                4, FALSE, FALSE
+            ),
             c("Range_1", "Range_2", "Range_3")
         )
     })
 
     test_that("cut throws error when no variable name supplies", {
-        expect_error(cut(ds$birthyr, 3),
-            "Must provide the name for the new variable")
+        expect_error(
+            cut(ds$birthyr, 3),
+            "Must provide the name for the new variable"
+        )
     })
 
 
@@ -55,18 +62,28 @@ with_mock_crunch({
                             value = list(
                                 class = "categorical",
                                 categories = list(
-                                    list(id = 1L,
+                                    list(
+                                        id = 1L,
                                         name = "one",
                                         numeric_value = NULL,
-                                        missing = FALSE),
-                                    list(id = 2L,
+                                        missing = FALSE
+                                    ),
+                                    list(
+                                        id = 2L,
                                         name = "two",
                                         numeric_value = NULL,
-                                        missing = FALSE),
-                                    list(id = 3L,
+                                        missing = FALSE
+                                    ),
+                                    list(
+                                        id = 3L,
                                         name = "three",
                                         numeric_value = NULL,
-                                        missing = FALSE))))),
+                                        missing = FALSE
+                                    )
+                                )
+                            )
+                        )
+                    ),
                     list(
                         `function` = "and",
                         args = list(
@@ -74,19 +91,30 @@ with_mock_crunch({
                                 `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
-                                    list(value = -1.4998629))),
-                            list(`function` = "<=",
+                                    list(value = -1.4998629)
+                                )
+                            ),
+                            list(
+                                `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
-                                    list(value = -0.4424))))),
-                    list(`function` = "and",
+                                    list(value = -0.4424)
+                                )
+                            )
+                        )
+                    ),
+                    list(
+                        `function` = "and",
                         args = list(
                             list(
                                 `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
-                                    list(value = -0.4424))),
-                            list(`function` = "<=",
+                                    list(value = -0.4424)
+                                )
+                            ),
+                            list(
+                                `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 0.6119)
@@ -94,13 +122,18 @@ with_mock_crunch({
                             )
                         )
                     ),
-                    list(`function` = "and",
+                    list(
+                        `function` = "and",
                         args = list(
-                            list(`function` = ">",
+                            list(
+                                `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
-                                    list(value = 0.6119))),
-                            list(`function` = "<=",
+                                    list(value = 0.6119)
+                                )
+                            ),
+                            list(
+                                `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 1.6693629)
@@ -118,50 +151,64 @@ with_mock_crunch({
             derivation = list(
                 `function` = "case",
                 args = list(
-                    list(column = I(1:3),
+                    list(
+                        column = I(1:3),
                         type = list(
                             value = list(
                                 class = "categorical",
                                 categories = list(
-                                    list(id = 1L,
+                                    list(
+                                        id = 1L,
                                         name = "one",
                                         numeric_value = NULL,
-                                        missing = FALSE),
-                                    list(id = 2L,
+                                        missing = FALSE
+                                    ),
+                                    list(
+                                        id = 2L,
                                         name = "two",
                                         numeric_value = NULL,
-                                        missing = FALSE),
-                                    list(id = 3L,
+                                        missing = FALSE
+                                    ),
+                                    list(
+                                        id = 3L,
                                         name = "three",
                                         numeric_value = NULL,
-                                        missing = FALSE)
+                                        missing = FALSE
+                                    )
                                 )
                             )
                         )
                     ),
-                    list(`function` = "and",
+                    list(
+                        `function` = "and",
                         args = list(
                             list(
                                 `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
-                                    list(value = -1.4998629))), list(`function` = "<",
-                                        args = list(
-                                            list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
-                                            list(value = -0.4424)
-                                        )
-                                    )
+                                    list(value = -1.4998629)
+                                )
+                            ), list(
+                                `function` = "<",
+                                args = list(
+                                    list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
+                                    list(value = -0.4424)
+                                )
+                            )
                         )
                     ),
-                    list(`function` = "and",
+                    list(
+                        `function` = "and",
                         args = list(
-                            list(`function` = ">=",
+                            list(
+                                `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = -0.4424)
                                 )
                             ),
-                            list(`function` = "<",
+                            list(
+                                `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 0.6119)
@@ -169,14 +216,17 @@ with_mock_crunch({
                             )
                         )
                     ),
-                    list(`function` = "and",
+                    list(
+                        `function` = "and",
                         args = list(
-                            list(`function` = ">=",
+                            list(
+                                `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 0.6119)
                                 )
-                            ), list(`function` = "<",
+                            ), list(
+                                `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 1.6693629)
@@ -196,29 +246,37 @@ with_mock_crunch({
                     list(
                         column = I(1:2),
                         type = list(
-                            value = list(class = "categorical",
+                            value = list(
+                                class = "categorical",
                                 categories = list(
-                                    list(id = 1L,
+                                    list(
+                                        id = 1L,
                                         name = "one",
                                         numeric_value = NULL,
-                                        missing = FALSE),
-                                    list(id = 2L,
+                                        missing = FALSE
+                                    ),
+                                    list(
+                                        id = 2L,
                                         name = "two",
                                         numeric_value = NULL,
-                                        missing = FALSE)
+                                        missing = FALSE
+                                    )
                                 )
                             )
                         )
                     ),
-                    list(`function` = "and",
+                    list(
+                        `function` = "and",
                         args = list(
-                            list(`function` = ">=",
+                            list(
+                                `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = -1.4967)
                                 )
                             ),
-                            list(`function` = "<",
+                            list(
+                                `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 0)
@@ -226,15 +284,18 @@ with_mock_crunch({
                             )
                         )
                     ),
-                    list(`function` = "and",
+                    list(
+                        `function` = "and",
                         args = list(
-                            list(`function` = ">=",
+                            list(
+                                `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 0)
                                 )
                             ),
-                            list(`function` = "<",
+                            list(
+                                `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 1.6662)
@@ -246,7 +307,8 @@ with_mock_crunch({
             )
         )
 
-        dig_lab <- list(name = "new_var",
+        dig_lab <- list(
+            name = "new_var",
             derivation = list(
                 `function` = "case",
                 args = list(
@@ -256,18 +318,24 @@ with_mock_crunch({
                             value = list(
                                 class = "categorical",
                                 categories = list(
-                                    list(id = 1L,
+                                    list(
+                                        id = 1L,
                                         name = "(-1.5,-0.44]",
                                         numeric_value = NULL,
-                                        missing = FALSE),
-                                    list(id = 2L,
+                                        missing = FALSE
+                                    ),
+                                    list(
+                                        id = 2L,
                                         name = "(-0.44,0.61]",
                                         numeric_value = NULL,
-                                        missing = FALSE),
-                                    list(id = 3L,
+                                        missing = FALSE
+                                    ),
+                                    list(
+                                        id = 3L,
                                         name = "(0.61,1.7]",
                                         numeric_value = NULL,
-                                        missing = FALSE)
+                                        missing = FALSE
+                                    )
                                 )
                             )
                         )
@@ -275,12 +343,15 @@ with_mock_crunch({
                     list(
                         `function` = "and",
                         args = list(
-                            list(`function` = ">",
-                                args = list(list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
+                            list(
+                                `function` = ">",
+                                args = list(
+                                    list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = -1.4998629)
                                 )
                             ),
-                            list(`function` = "<=",
+                            list(
+                                `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = -0.4424)
@@ -290,13 +361,16 @@ with_mock_crunch({
                     ),
                     list(
                         `function` = "and",
-                        args = list(list(`function` = ">",
-                            args = list(
-                                list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
-                                list(value = -0.4424)
-                            )
-                        ),
-                            list(`function` = "<=",
+                        args = list(
+                            list(
+                                `function` = ">",
+                                args = list(
+                                    list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
+                                    list(value = -0.4424)
+                                )
+                            ),
+                            list(
+                                `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 0.6119)
@@ -304,7 +378,8 @@ with_mock_crunch({
                             )
                         )
                     ),
-                    list(`function` = "and",
+                    list(
+                        `function` = "and",
                         args = list(
                             list(
                                 `function` = ">",
@@ -313,7 +388,8 @@ with_mock_crunch({
                                     list(value = 0.6119)
                                 )
                             ),
-                            list(`function` = "<=",
+                            list(
+                                `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"),
                                     list(value = 1.6693629)
@@ -327,8 +403,10 @@ with_mock_crunch({
 
 
         ########################################################################
-        basic_cut <- cut(ds$birthyr, 3, name = "new_var",
-            label = c("one", "two", "three"))
+        basic_cut <- cut(ds$birthyr, 3,
+            name = "new_var",
+            label = c("one", "two", "three")
+        )
         expect_is(basic_cut, "VariableDefinition")
         expect_equivalent(basic_cut, basic_output)
         expect_equivalent(
@@ -337,7 +415,8 @@ with_mock_crunch({
                 3,
                 name = "new_var",
                 label = c("one", "two", "three"),
-                right = FALSE)
+                right = FALSE
+            )
         )
 
         expect_equivalent(
@@ -346,14 +425,16 @@ with_mock_crunch({
                 c(-1.4967, 0, 1.6662),
                 name = "new_var",
                 label = c("one", "two"),
-                right = FALSE)
+                right = FALSE
+            )
         )
         expect_equivalent(
             dig_lab,
             cut(ds$birthyr,
                 3,
                 dig.lab = 2,
-                name = "new_var")
+                name = "new_var"
+            )
         )
     })
 
@@ -362,7 +443,8 @@ with_mock_crunch({
             cut(ds$birthyr,
                 breaks = c(-1.4967),
                 name = "new_var",
-                right = TRUE),
+                right = TRUE
+            ),
             "invalid number of breaks"
         )
 
@@ -371,7 +453,8 @@ with_mock_crunch({
                 breaks = c(-1.4967, 0, 1.6662, 3),
                 name = "new_var",
                 label = c("one", "two"),
-                right = TRUE),
+                right = TRUE
+            ),
             "There are 3 resulting categories but you only supplied 2 labels. Change number of breaks or the number of labels."
         )
         expect_error(
@@ -379,7 +462,8 @@ with_mock_crunch({
                 breaks = c(1, 1, 1),
                 name = "new_var",
                 label = c("one", "two"),
-                right = TRUE),
+                right = TRUE
+            ),
             paste0(sQuote("breaks"), " must be unique")
         )
     })
@@ -389,15 +473,19 @@ with_test_authentication({
     ds <- newDataset(df)
 
     test_that("cut returns the same thing for Crunch variables and identical vectors", {
-        ds$cat_var1 <- cut(ds$v1, 3, name = "new_var1",
-            label = c("one", "two", "three"))
+        ds$cat_var1 <- cut(ds$v1, 3,
+            name = "new_var1",
+            label = c("one", "two", "three")
+        )
         expect_identical(
             cut(df$v1, 3, label = c("one", "two", "three")),
             as.vector(ds$cat_var1)
         )
 
-        ds$cat_var2 <- cut(ds$v1, 3, name = "new_var2",
-            label = c("one", "two", "three"), right = FALSE)
+        ds$cat_var2 <- cut(ds$v1, 3,
+            name = "new_var2",
+            label = c("one", "two", "three"), right = FALSE
+        )
         expect_identical(
             cut(df$v1, 3, label = c("one", "two", "three"), right = FALSE),
             as.vector(ds$cat_var2)
@@ -407,7 +495,8 @@ with_test_authentication({
             c(-1.4967, 0, 1.6662),
             name = "new_var3",
             label = c("one", "two"),
-            right = FALSE)
+            right = FALSE
+        )
         expect_identical(
             cut(df$v1, c(-1.4967, 0, 1.6662), label = c("one", "two"), right = FALSE),
             as.vector(ds$cat_var3)
@@ -416,7 +505,8 @@ with_test_authentication({
         ds$cat_var4 <- cut(ds$v1,
             3,
             dig.lab = 2,
-            name = "new_var4")
+            name = "new_var4"
+        )
         expect_identical(
             cut(df$v1, 3, dig.lab = 2),
             as.vector(ds$cat_var4)
@@ -425,7 +515,8 @@ with_test_authentication({
         ds$cat_var5 <- cut(ds$v1,
             3,
             include.lowest = TRUE,
-            name = "new_var5")
+            name = "new_var5"
+        )
         expect_identical(
             cut(df$v1, 3, include.lowest = TRUE),
             as.vector(ds$cat_var5)
@@ -433,11 +524,15 @@ with_test_authentication({
 
         df$age <- sample(1:100, 20)
         ds$age <- df$age
-        ds$age4 <- cut(df$age, c(0, 30, 45, 65, 200),
-            c("youth", "adult", "middle-aged", "elderly"))
+        ds$age4 <- cut(
+            df$age, c(0, 30, 45, 65, 200),
+            c("youth", "adult", "middle-aged", "elderly")
+        )
         expect_identical(
-            cut(df$age, c(0, 30, 45, 65, 200),
-            c("youth", "adult", "middle-aged", "elderly")),
+            cut(
+                df$age, c(0, 30, 45, 65, 200),
+                c("youth", "adult", "middle-aged", "elderly")
+            ),
             as.vector(ds$age4)
         )
     })
