@@ -3,15 +3,18 @@ context("Deriving array variables")
 with_mock_crunch({
     ds <- loadDataset("test ds")
     test_that("deriveArray works with MR", {
-    expect_POST(ds$derived_mr <- deriveArray(list(ds$gender),
-                                             selections=list("Female"),
-                                             name="derivedMR"),
-                "https://app.crunch.io/api/datasets/1/variables/",
-                '{"derivation":{"function":"select_categories","args":',
-                '[{"function":"array","args":[{"function":"select","args":',
-                '[{"map":{"1":{"variable":"https://app.crunch.io/api/datasets',
-                '/1/variables/gender/"}}},{"value":["1"]}]}]},{"value":',
-                '["Female"]}]},"name":"derivedMR","alias":"derived_mr"}')
+        expect_POST(
+            ds$derived_mr <- deriveArray(list(ds$gender),
+                selections = list("Female"),
+                name = "derivedMR"
+            ),
+            "https://app.crunch.io/api/datasets/1/variables/",
+            '{"derivation":{"function":"select_categories","args":',
+            '[{"function":"array","args":[{"function":"select","args":',
+            '[{"map":{"1":{"variable":"https://app.crunch.io/api/datasets',
+            '/1/variables/gender/"}}},{"value":["1"]}]}]},{"value":',
+            '["Female"]}]},"name":"derivedMR","alias":"derived_mr"}'
+        )
     })
 })
 
@@ -32,7 +35,7 @@ with_test_authentication({
     #  Cat  Dog Bird
     #    6    4    6
 
-    vd <- deriveArray(list(ds$q1, ds$petloc$petloc_home), name="Derived pets")
+    vd <- deriveArray(list(ds$q1, ds$petloc$petloc_home), name = "Derived pets")
     test_that("deriveArray returns a VarDef", {
         expect_is(vd, "VariableDefinition")
     })
@@ -40,71 +43,106 @@ with_test_authentication({
     test_that("Sending a derived array vardef creates a derived array", {
         expect_true(is.CA(ds$derivedarray))
         expect_identical(names(subvariables(ds$derivedarray)), c("Pet", "Home"))
-        expect_identical(names(categories(ds$derivedarray)),
-            c("Cat", "Dog", "Bird", "Skipped", "Not Asked"))
+        expect_identical(
+            names(categories(ds$derivedarray)),
+            c("Cat", "Dog", "Bird", "Skipped", "Not Asked")
+        )
         expect_identical(as.vector(ds$derivedarray[[1]]), q1.values)
     })
 
-    ds$derivedmr <- deriveArray(list(ds$q1, ds$petloc$petloc_home), selections="Dog", name="Derived pets MR") # cat dog has id 2
+    ds$derivedmr <- deriveArray(list(ds$q1, ds$petloc$petloc_home), selections = "Dog", name = "Derived pets MR") # cat dog has id 2
     test_that("deriveArray can also derive MRs", {
         expect_true(is.MR(ds$derivedmr))
         expect_identical(names(subvariables(ds$derivedmr)), c("Pet", "Home"))
-        expect_identical(names(categories(ds$derivedmr)),
-                         c("Cat", "Dog", "Bird", "Skipped", "Not Asked"))
+        expect_identical(
+            names(categories(ds$derivedmr)),
+            c("Cat", "Dog", "Bird", "Skipped", "Not Asked")
+        )
         expect_identical(as.vector(ds$derivedmr[[1]]), q1.values)
         expect_true(is.selected(categories(ds$derivedmr)[[2]]))
     })
 
     test_that("Can edit metadata of the derived array, and parents are unaffected", {
         aliases(subvariables(ds$derivedarray)) <- c("dsub1", "dsub2")
-        expect_identical(aliases(subvariables(ds$derivedarray)),
-            c("dsub1", "dsub2"))
+        expect_identical(
+            aliases(subvariables(ds$derivedarray)),
+            c("dsub1", "dsub2")
+        )
         names(categories(ds$derivedarray))[1:2] <- c("one", "two")
-        expect_identical(names(categories(ds$derivedarray)),
-            c("one", "two", "Bird", "Skipped", "Not Asked"))
+        expect_identical(
+            names(categories(ds$derivedarray)),
+            c("one", "two", "Bird", "Skipped", "Not Asked")
+        )
         ds <- refresh(ds)
-        expect_identical(aliases(subvariables(ds$derivedarray)),
-            c("dsub1", "dsub2"))
-        expect_identical(names(categories(ds$derivedarray)),
-            c("one", "two", "Bird", "Skipped", "Not Asked"))
-        expect_equivalent(table(ds$derivedarray$dsub2),
-            structure(c(5, 3, 3), .Dim=3L,
-            .Dimnames=list(dsub2=c("one", "two", "Bird")),
-            class="table"))
+        expect_identical(
+            aliases(subvariables(ds$derivedarray)),
+            c("dsub1", "dsub2")
+        )
+        expect_identical(
+            names(categories(ds$derivedarray)),
+            c("one", "two", "Bird", "Skipped", "Not Asked")
+        )
+        expect_equivalent(
+            table(ds$derivedarray$dsub2),
+            structure(c(5, 3, 3),
+                .Dim = 3L,
+                .Dimnames = list(dsub2 = c("one", "two", "Bird")),
+                class = "table"
+            )
+        )
         ## Parent unaffected
         expect_true(is.Categorical(ds$q1))
-        expect_identical(names(categories(ds$q1)),
-            c("Cat", "Dog", "Bird", "Skipped", "Not Asked"))
+        expect_identical(
+            names(categories(ds$q1)),
+            c("Cat", "Dog", "Bird", "Skipped", "Not Asked")
+        )
     })
 
     ## Deep copy array, rename it, etc.
-    ds$petloc2 <- copy(ds$petloc, deep=TRUE, name="Other pet loc")
+    ds$petloc2 <- copy(ds$petloc, deep = TRUE, name = "Other pet loc")
     aliases(subvariables(ds$petloc2)) <- c("pl2_a", "pl2_b")
 
     ## Make a "flipped" version of that and the original
     ds$petloc_a <- deriveArray(list(ds$petloc2$pl2_a, ds$petloc$petloc_home),
-        name="Pet Location: Home", subreferences=list(list(name="Copy", alias="pla_copy"),
-        list(name="Original", alias="pla_orig")))
+        name = "Pet Location: Home", subreferences = list(
+            list(name = "Copy", alias = "pla_copy"),
+            list(name = "Original", alias = "pla_orig")
+        )
+    )
     ds$petloc_b <- deriveArray(list(ds$petloc2$pl2_b, ds$petloc$petloc_work),
-        name="Pet Location: Work", subreferences=list(list(name="Copy", alias="plb_copy"),
-        list(name="Original", alias="plb_orig")))
+        name = "Pet Location: Work", subreferences = list(
+            list(name = "Copy", alias = "plb_copy"),
+            list(name = "Original", alias = "plb_orig")
+        )
+    )
 
     test_that("Deriving arrays with subreferences specified", {
-        expect_identical(aliases(subvariables(ds$petloc_a)),
-            c("pla_copy", "pla_orig"))
-        expect_identical(names(subvariables(ds$petloc_a)),
-            c("Copy", "Original"))
+        expect_identical(
+            aliases(subvariables(ds$petloc_a)),
+            c("pla_copy", "pla_orig")
+        )
+        expect_identical(
+            names(subvariables(ds$petloc_a)),
+            c("Copy", "Original")
+        )
     })
 
     ## Make derived array of derived array
-    ds$metapetloc <- deriveArray(list(ds$petloc$petloc_home, ds$petloc_a$pla_copy,
-        ds$petloc_b$plb_copy, ds$derivedarray$dsub2),
-        name="Derived from derived and real")
+    ds$metapetloc <- deriveArray(list(
+        ds$petloc$petloc_home, ds$petloc_a$pla_copy,
+        ds$petloc_b$plb_copy, ds$derivedarray$dsub2
+    ),
+    name = "Derived from derived and real"
+    )
     test_that("Derived arrays of derived array subvariables with different categories", {
-        expect_identical(names(subvariables(ds$metapetloc)),
-            c("Home", "Copy", "Copy", "Home"))
-        expect_identical(names(categories(ds$metapetloc)),
-            c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "one", "two"))
+        expect_identical(
+            names(subvariables(ds$metapetloc)),
+            c("Home", "Copy", "Copy", "Home")
+        )
+        expect_identical(
+            names(categories(ds$metapetloc)),
+            c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "one", "two")
+        )
 
         t1 <- table(ds$metapetloc[[1]])
         expect_identical(names(t1), c("Cat", "Dog", "Bird", "one", "two"))
@@ -115,14 +153,22 @@ with_test_authentication({
         expect_identical(as.numeric(table(ds$metapetloc[[4]])), c(0, 0, 3, 5, 3))
     })
 
-    ds$metapet_combined <- combine(ds$metapetloc, name="Metapet combined",
-        combinations=list(list(name="Cat", categories=c("Cat", "one")),
-            list(name="Dog", categories=c("Dog", "two"))))
+    ds$metapet_combined <- combine(ds$metapetloc,
+        name = "Metapet combined",
+        combinations = list(
+            list(name = "Cat", categories = c("Cat", "one")),
+            list(name = "Dog", categories = c("Dog", "two"))
+        )
+    )
     test_that("Combine categories of derived array", {
-        expect_identical(names(subvariables(ds$metapet_combined)),
-            c("Home", "Copy", "Copy", "Home"))
-        expect_identical(names(categories(ds$metapet_combined)),
-            c("Cat", "Dog", "Bird", "Skipped", "Not Asked"))
+        expect_identical(
+            names(subvariables(ds$metapet_combined)),
+            c("Home", "Copy", "Copy", "Home")
+        )
+        expect_identical(
+            names(categories(ds$metapet_combined)),
+            c("Cat", "Dog", "Bird", "Skipped", "Not Asked")
+        )
 
         t1 <- table(ds$metapet_combined[[1]])
         expect_identical(names(t1), c("Cat", "Dog", "Bird"))
@@ -137,17 +183,25 @@ with_test_authentication({
     ds <- appendDataset(ds, part2)
     test_that("When appending, derived arrays get data (or missing, as appropriate)", {
         ## No Data is added to the categories here
-        expect_identical(names(categories(ds$metapetloc)),
-            c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "one", "two", "No Data"))
+        expect_identical(
+            names(categories(ds$metapetloc)),
+            c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "one", "two", "No Data")
+        )
         ## metapetloc: subvar 1 is derived from petloc$petloc_home
-        expect_identical(as.numeric(table(ds$metapetloc[[1]])),
-            2 * c(5, 3, 3, 0, 0))
+        expect_identical(
+            as.numeric(table(ds$metapetloc[[1]])),
+            2 * c(5, 3, 3, 0, 0)
+        )
         ## subvar 2 is from petloc_a$pla_1, which points to petloc2, a deep copy
-        expect_identical(as.numeric(table(ds$metapetloc[[2]])),
-            c(5, 3, 3, 0, 0))
+        expect_identical(
+            as.numeric(table(ds$metapetloc[[2]])),
+            c(5, 3, 3, 0, 0)
+        )
         ## likewise for subvar 3
-        expect_identical(as.numeric(table(ds$metapetloc[[3]])),
-            c(6, 4, 6, 0, 0))
+        expect_identical(
+            as.numeric(table(ds$metapetloc[[3]])),
+            c(6, 4, 6, 0, 0)
+        )
         ## 4 comes from derivedarray$dsub2, which comes from petloc$petloc_home,
         ## but with different category names
 
@@ -156,31 +210,51 @@ with_test_authentication({
         # dsub2#
         #  Cat  Dog Bird  one  two
         #    5    3    6    5    3
-        expect_identical(as.numeric(table(ds$metapetloc[[4]])),
-            2 * c(0, 0, 3, 5, 3))
+        expect_identical(
+            as.numeric(table(ds$metapetloc[[4]])),
+            2 * c(0, 0, 3, 5, 3)
+        )
     })
     test_that("Combined categories on top of derived array also gets the right data", {
-        expect_identical(names(categories(ds$metapet_combined)),
-            c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "No Data"))
-        expect_identical(as.numeric(table(ds$metapet_combined[[1]])),
-            2 * c(5, 3, 3))
-        expect_identical(as.numeric(table(ds$metapet_combined[[2]])),
-            c(5, 3, 3))
-        expect_identical(as.numeric(table(ds$metapet_combined[[3]])),
-            c(6, 4, 6))
-        expect_identical(as.numeric(table(ds$metapet_combined[[4]])),
-            2 * c(5, 3, 3))
+        expect_identical(
+            names(categories(ds$metapet_combined)),
+            c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "No Data")
+        )
+        expect_identical(
+            as.numeric(table(ds$metapet_combined[[1]])),
+            2 * c(5, 3, 3)
+        )
+        expect_identical(
+            as.numeric(table(ds$metapet_combined[[2]])),
+            c(5, 3, 3)
+        )
+        expect_identical(
+            as.numeric(table(ds$metapet_combined[[3]])),
+            c(6, 4, 6)
+        )
+        expect_identical(
+            as.numeric(table(ds$metapet_combined[[4]])),
+            2 * c(5, 3, 3)
+        )
     })
     test_that("The array we edited in the beginning still has its edits after appending", {
-        expect_identical(aliases(subvariables(ds$derivedarray)),
-            c("dsub1", "dsub2"))
-        expect_identical(names(categories(ds$derivedarray)),
-            c("one", "two", "Bird", "Skipped", "Not Asked"))
+        expect_identical(
+            aliases(subvariables(ds$derivedarray)),
+            c("dsub1", "dsub2")
+        )
+        expect_identical(
+            names(categories(ds$derivedarray)),
+            c("one", "two", "Bird", "Skipped", "Not Asked")
+        )
         ## This is the data we should see in metapetloc[[4]]. It's correct here.
-        expect_equivalent(table(ds$derivedarray$dsub2),
-            structure(c(10, 6, 6), .Dim=3L,
-            .Dimnames=list(dsub2=c("one", "two", "Bird")),
-            class="table"))
+        expect_equivalent(
+            table(ds$derivedarray$dsub2),
+            structure(c(10, 6, 6),
+                .Dim = 3L,
+                .Dimnames = list(dsub2 = c("one", "two", "Bird")),
+                class = "table"
+            )
+        )
     })
 
     ## Append a dataset where the categories in one of the base variables don't quite match
@@ -191,11 +265,15 @@ with_test_authentication({
     ds <- appendDataset(ds, part3)
 
     test_that("petloc is updated appropriately", {
-        expect_identical(aliases(subvariables(ds$petloc)),
-            c("petloc_home", "petloc_work", "petloc_school"))
+        expect_identical(
+            aliases(subvariables(ds$petloc)),
+            c("petloc_home", "petloc_work", "petloc_school")
+        )
         ## No Data comes in after appending because petloc_work and petloc_school have data gaps
-        expect_identical(names(categories(ds$petloc)),
-            c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "Beaver", "No Data"))
+        expect_identical(
+            names(categories(ds$petloc)),
+            c("Cat", "Dog", "Bird", "Skipped", "Not Asked", "Beaver", "No Data")
+        )
     })
 
     # skip("Derivations of derivations need some work in zz9")
