@@ -63,13 +63,13 @@ with_mock_crunch({
     })
 
     test_that("Filter entity is.public", {
-        expect_false(is.public(f))
+        expect_false(is.public(filters(ds)[["Occasional Political Interest"]]))
         expect_PATCH(
-            is.public(f) <- TRUE,
+            is.public(filters(ds)[["Occasional Political Interest"]]) <- TRUE,
             "https://app.crunch.io/api/datasets/1/filters/filter1/",
             '{"is_public":true}'
         )
-        expect_no_request(is.public(f) <- FALSE)
+        expect_no_request(is.public(filters(ds)[["Occasional Political Interest"]]) <- FALSE)
     })
 
     test_that("can get and set the team for filters", {
@@ -294,14 +294,14 @@ with_test_authentication({
         teams <- getTeams()
         teams[["A new team for filters"]] <- list()
         teams[["A different team for filters"]] <- list()
-        
+
         # can set a team
         team(team_filter) <- getTeams()[["A new team for filters"]]
         expect_identical(
-            team(team_filter), 
+            team(team_filter),
             getTeams()[["A new team for filters"]]
         )
-        
+
         # can change a team (with a URL this time)
         team_url <- self(getTeams()[["A different team for filters"]])
         team(team_filter) <- team_url
@@ -309,7 +309,7 @@ with_test_authentication({
             team(team_filter),
             getTeams()[["A different team for filters"]]
         )
-        
+
         # can remove the team
         team(team_filter) <- NULL
         expect_null(team(team_filter))
