@@ -89,12 +89,7 @@ with_mock_crunch({
         "https://app.crunch.io/api/datasets/1/folders/2/",
         " ",
         '{"element":"shoji:catalog","index":{',
-        '"https://app.crunch.io/api/datasets/1/variables/birthyr/":{}},',
-        '"graph":[',
-        '"https://app.crunch.io/api/datasets/1/variables/starttime/",',
-        '"https://app.crunch.io/api/datasets/1/variables/catarray/",',
-        '"https://app.crunch.io/api/datasets/1/variables/birthyr/"',
-        "]}"
+        '"https://app.crunch.io/api/datasets/1/variables/birthyr/":{}}}'
     )
     test_that("mv variables to existing folder, selecting from dataset", {
         expect_PATCH(
@@ -190,12 +185,7 @@ with_mock_crunch({
             ds %>% cd("Group 1") %>% mv("Nested", "../Group 2"),
             "https://app.crunch.io/api/datasets/1/folders/2/",
             '{"element":"shoji:catalog","index":{',
-            '"https://app.crunch.io/api/datasets/1/folders/3/":{}},',
-            '"graph":[',
-            '"https://app.crunch.io/api/datasets/1/variables/starttime/",',
-            '"https://app.crunch.io/api/datasets/1/variables/catarray/",',
-            '"https://app.crunch.io/api/datasets/1/folders/3/"',
-            "]}"
+            '"https://app.crunch.io/api/datasets/1/folders/3/":{}}}'
         )
     })
 
@@ -279,6 +269,16 @@ with_mock_crunch({
             ds %>% rmdir("Group 1/Nested"),
             "Must confirm deleting folder"
         )
+        expect_message(
+            expect_error(
+                ds %>% rmdir("Group 2"),
+                "Must confirm deleting folder"
+            ),
+            paste0(
+                "This folder contains 2 objects: .*starttime.* and ",
+                ".*Cat Array.*"
+            )
+        )
         with_consent({
             expect_DELETE(
                 ds %>% rmdir("Group 1/Nested"),
