@@ -3,112 +3,153 @@ context("Categorical Array")
 with_mock_crunch({
     ds <- loadDataset("test ds")
     test_that("makeArray creates a VariableDefinition with dataset subset", {
-        expect_json_equivalent(makeArray(ds[,"gender"], name="Gender array"),
+        expect_json_equivalent(
+            makeArray(ds[, "gender"], name = "Gender array"),
             list(
-                name="Gender array",
-                subvariables=I("https://app.crunch.io/api/datasets/1/variables/gender/"),
-                type="categorical_array"
-            ))
+                name = "Gender array",
+                subvariables = I("https://app.crunch.io/api/datasets/1/variables/gender/"),
+                type = "categorical_array"
+            )
+        )
     })
     test_that("makeArray creates a VariableDefinition with variables subset", {
-        expect_json_equivalent(makeArray(variables(ds)[names(ds) == "gender"],
-            name="Gender array 2"),
+        expect_json_equivalent(
+            makeArray(variables(ds)[names(ds) == "gender"],
+                name = "Gender array 2"
+            ),
             list(
-                name="Gender array 2",
-                subvariables=I("https://app.crunch.io/api/datasets/1/variables/gender/"),
-                type="categorical_array"
-            ))
+                name = "Gender array 2",
+                subvariables = I("https://app.crunch.io/api/datasets/1/variables/gender/"),
+                type = "categorical_array"
+            )
+        )
     })
     test_that("makeMR creates a VariableDefinition", {
-        expect_json_equivalent(makeMR(ds[,"gender"], name="Gender MR", selections="Male"),
+        expect_json_equivalent(
+            makeMR(ds[, "gender"], name = "Gender MR", selections = "Male"),
             list(
-                name="Gender MR",
-                subvariables=I("https://app.crunch.io/api/datasets/1/variables/gender/"),
-                type="multiple_response",
-                selected_categories=I("Male")
-            ))
+                name = "Gender MR",
+                subvariables = I("https://app.crunch.io/api/datasets/1/variables/gender/"),
+                type = "multiple_response",
+                selected_categories = I("Male")
+            )
+        )
     })
 
     no.name <- "Must provide the name for the new variable"
     no.match <- "No variables supplied"
-    no.selections <- paste("Must provide the names of the category or",
-        "categories that indicate the dichotomous selection")
+    no.selections <- paste(
+        "Must provide the names of the category or",
+        "categories that indicate the dichotomous selection"
+    )
     invalid.selection <- "not found in variable's categories"
     not.categorical <- "are not Categorical"
     test_that("makeArray error conditions", {
         expect_error(makeArray(), no.name)
-        expect_error(makeArray(ds[,"gender"]), no.name)
-        expect_error(makeArray(ds[grep("NO variables", names(ds))], name="foo"),
-            no.match)
+        expect_error(makeArray(ds[, "gender"]), no.name)
+        expect_error(
+            makeArray(ds[grep("NO variables", names(ds))], name = "foo"),
+            no.match
+        )
     })
     test_that("makeMR error conditions", {
         expect_error(makeMR(), no.selections)
-        expect_error(makeMR(ds[,"gender"]), no.selections)
-        expect_error(makeMR(ds[,"gender"], selections="Male"), no.name)
-        expect_error(makeMR(ds[grep("NO variables", names(ds))], name="foo",
-            selections="X"),
-            no.match)
-        expect_error(makeMR(ds[,"gender"], selections="Other", name="Gen"),
-            invalid.selection)
-        expect_error(makeMR(ds[,c("gender", "birthyr")], selections="Male",
-            name="Gen"),
-            not.categorical)
-        expect_error(makeMR(ds[,c("gender", "NOTAVARIABLE")], selections="Male",
-            name="Gen"),
-            "Undefined columns selected: NOTAVARIABLE")
+        expect_error(makeMR(ds[, "gender"]), no.selections)
+        expect_error(makeMR(ds[, "gender"], selections = "Male"), no.name)
+        expect_error(
+            makeMR(ds[grep("NO variables", names(ds))],
+                name = "foo",
+                selections = "X"
+            ),
+            no.match
+        )
+        expect_error(
+            makeMR(ds[, "gender"], selections = "Other", name = "Gen"),
+            invalid.selection
+        )
+        expect_error(
+            makeMR(ds[, c("gender", "birthyr")],
+                selections = "Male",
+                name = "Gen"
+            ),
+            not.categorical
+        )
+        expect_error(
+            makeMR(ds[, c("gender", "NOTAVARIABLE")],
+                selections = "Male",
+                name = "Gen"
+            ),
+            "Undefined columns selected: NOTAVARIABLE"
+        )
     })
 
     test_that("makeMRFromText errors correctly", {
-        expect_error(makeMRFromText(ds$var, "; "),
-            "Must supply a name for the new variable")
-        expect_error(makeMRFromText(ds$birthyr,  name = "name"),
+        expect_error(
+            makeMRFromText(ds$var, "; "),
+            "Must supply a name for the new variable"
+        )
+        expect_error(makeMRFromText(ds$birthyr, name = "name"),
             paste0(dQuote("ds$birthyr"), " is of class NumericVariable, it must be a Crunch TextVariable."),
-            fixed = TRUE)
+            fixed = TRUE
+        )
     })
 
     test_that("createSubvarDeriv generates the correct variable definition", {
         expected <- list(
             `function` = "case",
             args = list(
-                list(column = I(1:3),
-                     type = list(
-                         value = list(class = "categorical",
-                                      categories = list(
-                                          list(id = 1,
-                                               name = "No Data",
-                                               numeric_value = NA,
-                                               missing = TRUE),
-                                          list(id = 2,
-                                               name = "Yes",
-                                               numeric_value = NA,
-                                               missing = FALSE),
-                                          list(id = 3,
-                                               name = "No",
-                                               numeric_value = NA,
-                                               missing = FALSE)
-                                      )
-                         )
-                     )
+                list(
+                    column = I(1:3),
+                    type = list(
+                        value = list(
+                            class = "categorical",
+                            categories = list(
+                                list(
+                                    id = 1,
+                                    name = "No Data",
+                                    numeric_value = NA,
+                                    missing = TRUE
+                                ),
+                                list(
+                                    id = 2,
+                                    name = "Yes",
+                                    numeric_value = NA,
+                                    missing = FALSE
+                                ),
+                                list(
+                                    id = 3,
+                                    name = "No",
+                                    numeric_value = NA,
+                                    missing = FALSE
+                                )
+                            )
+                        )
+                    )
                 ),
-                list(`function` = "is_missing",
-                     args = list(
-                         list(variable = "https://app.crunch.io/api/datasets/1/variables/textVar/")
-                     )
+                list(
+                    `function` = "is_missing",
+                    args = list(
+                        list(variable = "https://app.crunch.io/api/datasets/1/variables/textVar/")
+                    )
                 ),
-                list(`function` = "~=",
-                     args = list(
-                         list(variable = "https://app.crunch.io/api/datasets/1/variables/textVar/"),
-                         list(value = "^oak; |; oak; |; oak$|^oak$"))
+                list(
+                    `function` = "~=",
+                    args = list(
+                        list(variable = "https://app.crunch.io/api/datasets/1/variables/textVar/"),
+                        list(value = "^oak; |; oak; |; oak$|^oak$")
+                    )
                 )
             ),
             references = list(name = "oak", alias = "textVar_oak")
         )
-         varDef <- createSubvarDeriv(ds$textVar, str = "oak",
-             delim = "; ",
-             selected = "Yes",
-             not_selected = "No",
-             unanswered = NA)
-         expect_equivalent(varDef, expected)
+        varDef <- createSubvarDeriv(ds$textVar,
+            str = "oak",
+            delim = "; ",
+            selected = "Yes",
+            not_selected = "No",
+            unanswered = NA
+        )
+        expect_equivalent(varDef, expected)
     })
 
     test_that("escapeRegex escapes all metacharacters", {
@@ -126,7 +167,7 @@ with_mock_crunch({
         expect_true(grepl(rx, "birch; maple"))
         expect_false(grepl(rx, "birch; sugar maple"))
         expect_false(grepl(rx, "maple butter; oak"))
-        #test delimiters that are regex characters
+        # test delimiters that are regex characters
         expect_true(grepl(buildDelimRegex("maple", "| "), "oak| maple| birch"))
         expect_false(grepl(buildDelimRegex("maple", "| "), "oak| sugar maple| birch"))
     })
@@ -135,28 +176,33 @@ with_mock_crunch({
         ds2 <- loadDataset("https://app.crunch.io/api/datasets/mr_from_delim/")
         trees <- c("birch", "sugar maple", "maple butter", "oak", "maple")
         expected <- VariableDefinition(
-            derivation=zfunc(
+            derivation = zfunc(
                 "select_categories", zfunc(
-                    "array",  zfunc(
+                    "array", zfunc(
                         "select",
-                        list(map=lapply(trees, function (tree) {
+                        list(map = lapply(trees, function(tree) {
                             return(createSubvarDeriv(ds2$delimed_text,
-                                                   str = tree,
-                                                   delim = "; ",
-                                                   selected = "Yes",
-                                                   not_selected = "No",
-                                                   unanswered = NA))
+                                str = tree,
+                                delim = "; ",
+                                selected = "Yes",
+                                not_selected = "No",
+                                unanswered = NA
+                            ))
                         })),
-                        list(value=I(c(1, 2, 3, 4, 5)))
+                        list(value = I(c(1, 2, 3, 4, 5)))
                     )
                 ),
-                list(value=I("selected"))),
-            name="New Mr")
-        varDef <- makeMRFromText(ds2$delimed_text, delim = "; ",
-                              name = "New Mr",
-                              selected = "Yes",
-                              not_selected = "No",
-                              unanswered = NA)
+                list(value = I("selected"))
+            ),
+            name = "New Mr"
+        )
+        varDef <- makeMRFromText(ds2$delimed_text,
+            delim = "; ",
+            name = "New Mr",
+            selected = "Yes",
+            not_selected = "No",
+            unanswered = NA
+        )
         expect_equivalent(varDef, expected)
     })
 })
@@ -164,7 +210,7 @@ with_mock_crunch({
 with_test_authentication({
     whereas("We bind with makeArray", {
         ds <- newDataset(mrdf)
-        ds$arrayVar <- makeArray(ds[1:3], name="arrayVar")
+        ds$arrayVar <- makeArray(ds[1:3], name = "arrayVar")
 
         test_that("can make Categorical Array with Dataset subset", {
             expect_equal(c("arrayVar", "v4"), names(ds))
@@ -179,7 +225,7 @@ with_test_authentication({
 
     whereas("Testing dichotomizing and undichotomizing", {
         ds <- newDataset(mrdf)
-        ds$arrayVar <- makeArray(ds[c("mr_1", "mr_2", "mr_3")], name="arrayVar")
+        ds$arrayVar <- makeArray(ds[c("mr_1", "mr_2", "mr_3")], name = "arrayVar")
         var <- ds$arrayVar
         test_that("setup to make MultipleResponse from CategoricalArray", {
             expect_true(is.CA(var))
@@ -225,7 +271,7 @@ with_test_authentication({
         ds <- newDataset(mrdf)
         cast.these <- grep("mr_", names(ds))
         ds[cast.these] <- lapply(ds[cast.these], castVariable, "categorical")
-        ds$arrayVar <- makeMR(ds[cast.these], name="arrayVar", selections="1.0")
+        ds$arrayVar <- makeMR(ds[cast.these], name = "arrayVar", selections = "1.0")
         var <- ds$arrayVar
         expect_true(is.Multiple(var))
 
