@@ -72,6 +72,12 @@ with_mock_crunch({
             "Variable birthyr is hidden"
         )
     })
+    test_that("joinDatasets with copy=FALSE is (no longer/not yet) valid", {
+        expect_error(
+            joinDatasets(ds1, ds2, by.x = ds1$birthyr, ds2$birthyr, copy=FALSE),
+            "Virtual joins are not yet supported."
+        )
+    })
 
     test_that("merge a subset of variables", {
         expect_warning(
@@ -229,8 +235,8 @@ printed_order_apidocs2_merge_by_stringid <- c(
     "        Wave",
     "[+] __hidden__",
     "    [+] Example dataset",
-    "        Case ID",
-    "        Weight"
+    "        Weight",
+    "        Case ID"
 )
 
 printed_order_apidocs2_merge_by_caseid <- c(
@@ -371,14 +377,7 @@ with_test_authentication({
                     c(
                         "[+] Key Pet Indicators",
                         "    Pet",
-                        "    Pets by location",
-                        "[+] Dog Metrics",
-                        "    [+] Number of dogs by type",
-                        "        (Empty group)",
-                        "[+] Details",
-                        "    (Empty group)",
-                        "[+] Dimensions",
-                        "    (Empty group)"
+                        "    Pets by location"
                     ),
                     sep = "", collapse = "\n"
                 )
